@@ -27,18 +27,37 @@ EasyBuild support for installing EasyBuild, implemented as an easyblock
 
 @author: Kenneth Hoste (UGent)
 """
+import copy
 import os
 
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.easyblocks.generic.pythonpackage import PythonPackage
+from easybuild.tools.modules import get_software_root_env_var_name
 from easybuild.tools.ordereddict import OrderedDict
 from easybuild.tools.utilities import flatten
 
+
 # note: we can't use EB_EasyBuild as easyblock name, as that would require an easyblock named 'easybuild.py',
 #       which would screw up namespacing and create all kinds of problems (e.g. easyblocks not being found anymore)
 class EB_EasyBuildMeta(PythonPackage):
     """Support for install EasyBuild."""
 
+    def __init__(self, *args, **kwargs):
+        """Initialize custom class variables."""
+        super(EB_EasyBuildMeta, self).__init__(*args, **kwargs)
+        self.orig_orig_environ = None
+
+    def check_readiness_step(self):
+        """Make sure EasyBuild can be installed with a loaded EasyBuild module."""
+        env_var_name = get_software_root_env_var_name(self.name)
+        if env_var_name in os.environ:
+            os.environ.pop(env_var_name)
+            self.log.debug("$%s is unset so EasyBuild can be installed with a loaded EasyBuild module" % env_var_name)
+        else:
+            self.log.debug("Not unsetting $%s since it's not set" % env_var_name)
+
+        super(EB_EasyBuildMeta, self).check_readiness_step()
+
     def build_step(self):
         """No building for EasyBuild packages."""
         pass
@@ -120,4 +139,23 @@ class EB_EasyBuildMeta(PythonPackage):
                            ('eb', '-e ConfigureMake -a')
                           ]
 
+        # (temporary) cleanse copy of original environment to avoid conflict with (potentially) loaded EasyBuild module
+        self.orig_orig_environ = copy.deepcopy(self.orig_environ)
+        for env_var in ['_LMFILES_', 'LOADEDMODULES']:
+            if env_var in self.orig_environ:
+                self.orig_environ.pop(env_var)
+                os.environ.pop(env_var)
+                self.log.debug("Unset $%s in current env and copy of original env to make sanity check work" % env_var)
+
         super(EB_EasyBuildMeta, self).sanity_check_step(custom_paths=custom_paths, custom_commands=custom_commands)
+
+    def make_module_step(self, fake=False):
+        """Create module file, before copy of original environment that was tampered with is restored."""
+        modpath = super(EB_EasyBuildMeta, self).make_module_step(fake=fake)
+
+        if not fake:
+            # restore copy of original environment
+            self.orig_environ = copy.deepcopy(self.orig_orig_environ)
+            self.log.debug("Restored copy of original environment")
+
+        return modpath
