@@ -92,9 +92,9 @@ class EB_QuantumESPRESSO(ConfigureMake):
         dflags = []
 
         comp_fam_dflags = {
-                           toolchain.INTELCOMP: '-D__INTEL',
-                           toolchain.GCC: '-D__GFORTRAN -D__STD_F95',
-                          }
+            toolchain.INTELCOMP: '-D__INTEL',
+            toolchain.GCC: '-D__GFORTRAN -D__STD_F95',
+        }
         dflags.append(comp_fam_dflags[self.toolchain.comp_family()])
 
         libfft = os.getenv('LIBFFT')
@@ -117,6 +117,9 @@ class EB_QuantumESPRESSO(ConfigureMake):
         if self.cfg['with_scalapack']:
             dflags.append(" -D__SCALAPACK")
 
+        # always include -w to supress warnings
+        dflags.append('-w')
+
         repls.append(('DFLAGS', ' '.join(dflags), False))
 
         # complete C/Fortran compiler and LD flags
@@ -312,7 +315,6 @@ class EB_QuantumESPRESSO(ConfigureMake):
         if 'yambo' in self.cfg['makeopts']:
             yambo_bins = ["a2y", "p2y", "yambo", "ypp"]
 
-
         pref = self.install_subdir
 
         custom_paths = {
